@@ -1,6 +1,6 @@
 package Package::Stash;
 BEGIN {
-  $Package::Stash::VERSION = '0.16'; # TRIAL
+  $Package::Stash::VERSION = '0.17'; # TRIAL
 }
 use strict;
 use warnings;
@@ -56,37 +56,37 @@ use Package::DeprecationManager -deprecations => {
 };
 
 sub add_package_symbol {
-    deprecated('add_package_symbol is deprecated, please use add_symbol');
+    #deprecated('add_package_symbol is deprecated, please use add_symbol');
     shift->add_symbol(@_);
 }
 
 sub remove_package_glob {
-    deprecated('remove_package_glob is deprecated, please use remove_glob');
+    #deprecated('remove_package_glob is deprecated, please use remove_glob');
     shift->remove_glob(@_);
 }
 
 sub has_package_symbol {
-    deprecated('has_package_symbol is deprecated, please use has_symbol');
+    #deprecated('has_package_symbol is deprecated, please use has_symbol');
     shift->has_symbol(@_);
 }
 
 sub get_package_symbol {
-    deprecated('get_package_symbol is deprecated, please use get_symbol');
+    #deprecated('get_package_symbol is deprecated, please use get_symbol');
     shift->get_symbol(@_);
 }
 
 sub get_or_add_package_symbol {
-    deprecated('get_or_add_package_symbol is deprecated, please use get_or_add_symbol');
+    #deprecated('get_or_add_package_symbol is deprecated, please use get_or_add_symbol');
     shift->get_or_add_symbol(@_);
 }
 
 sub remove_package_symbol {
-    deprecated('remove_package_symbol is deprecated, please use remove_symbol');
+    #deprecated('remove_package_symbol is deprecated, please use remove_symbol');
     shift->remove_symbol(@_);
 }
 
 sub list_all_package_symbols {
-    deprecated('list_all_package_symbols is deprecated, please use list_all_symbols');
+    #deprecated('list_all_package_symbols is deprecated, please use list_all_symbols');
     shift->list_all_symbols(@_);
 }
 
@@ -102,7 +102,7 @@ Package::Stash - routines for manipulating stashes
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -281,7 +281,7 @@ This module is a factoring out of code that used to live here
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Jesse Luehrs.
+This software is copyright (c) 2011 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
